import { InboxOutlined } from "@ant-design/icons";
import {
  Card,
  Col,
  Form,
  Input,
  message,
  Row,
  Upload,
  UploadProps,
} from "antd";
import { useState } from "react";
import "./index.less";
const { Dragger } = Upload;
const { Meta } = Card;

interface IProps {
  onChange: Function;
}

const BasicForm = (props: IProps) => {
  const [preview, setPreivew] = useState({
    coverUrl: "",
    title: "标题",
    summary: "摘要",
  });
  const [form] = Form.useForm();

  const onValuesChange = (_: any, all: any) => {
    setPreivew((p) => ({ ...p, ...all }));
  };

  const coverDragger: UploadProps = {
    name: "file",
    multiple: true,
    action: "/api/upload",
    onChange(info) {
      const { status } = info.file;
      if (status !== "uploading") console.log(info.file, info.fileList);
      if (status === "done") {
        const { code, data } = info.file.response;
        if (code === 10000) {
          message.success(`${info.file.name} 文件上传成功`);
          const { MediaUrl } = data;
          setPreivew((p) => ({ ...p, coverUrl: MediaUrl }));
        }
      } else if (status === "error") {
        message.error(`${info.file.name} 文件上传失败`);
      }
    },
    onDrop(e) {
      console.log("Dropped files", e.dataTransfer.files);
    },
  };

  return (
    <div>
      <Row gutter={24}>
        <Col span={12}>
          <Form form={form} onValuesChange={onValuesChange}>
            <Form.Item>
              <Dragger {...coverDragger} maxCount={1}>
                <p className="ant-upload-drag-icon">
                  <InboxOutlined />
                </p>
                <p className="ant-upload-text">点击或拖拽文件到此区域上传</p>
                <p className="ant-upload-hint">支持单个或批量上传</p>
              </Dragger>
            </Form.Item>
            <Form.Item name="title" rules={[{ required: true }]}>
              <Input type="text" placeholder="标题" />
            </Form.Item>
            <Form.Item
              name="summary"
              rules={[{ required: true }]}
              style={{ marginBottom: 0 }}
            >
              <Input.TextArea
                placeholder="摘要"
                style={{ height: 120, resize: "none" }}
              />
            </Form.Item>
          </Form>
        </Col>
        <Col span={12}>
          <div
            className="preview-course"
            style={{
              backgroundImage: !preview.coverUrl
                ? `linear-gradient(
              to right,
              #e95659,
              #e15084,
              #c55aaa,
              #976bc4,
              #5678ce
            )`
                : `url(${preview.coverUrl})`,
            }}
          >
            <div className="mask">
              <p className="title">{preview.title}</p>
              <p className="summary">{preview.summary} </p>
            </div>
          </div>
        </Col>
      </Row>
    </div>
  );
};

export default BasicForm;
